function []=burg1(priklad) 
%% 1D Burgersova rovnice s vazkosti: u_t+u.u_x=eps.u_{xx}, dic program
%
% vstupni udaje:
%
% priklad ... cislo prikladu, data jsou v souboru burg**.txt, napr.
%                             je-li priklad=1, pak v souboru burg01.txt
% metoda  ... cislo metody = 1, Godunov
%                          = 2, Engquist-Osher
%                          = 3, Van Leer
%                          = 4, Rusakov
%
% vzorove volani :   burg1(1); % priklad 1, metoda Godunov
%
% pouziva: m-funkce: brg1.m, flux.m, u0.m
%          data:     burg**.txt, kde za ** volime 01, 02, ...,99
% pro kazdy typ pocatecni podminky je treba editovat soubor u0.m
% a upravit udaj PP v datovem souboru burg**.txt
%% cteni a tisk vstupnich dat
clc;
met=char('Godunov','Van Leer','Engquist--Osher','Rusakov');
euler=char('explicitni Eulerova','implicitni Eulerova');       
priklad=sprintf('%02d',priklad);
fprintf('\n***Burgersova rovnice s vazkosti v jedne dimenzi***\n');
% cteni vstupniho souboru
fid=fopen(['burg',priklad,'.txt'],'rt');
if fid < 0
  error('soubor %s neexistuje',['brg',priklad,'.txt']);
end
tline=fgetl(fid); L=sscanf(tline,'%e',1);
tline=fgetl(fid); T=sscanf(tline,'%e',1);
tline=fgetl(fid); N=sscanf(tline,'%d',1);
tline=fgetl(fid); M=sscanf(tline,'%d',1);
tline=fgetl(fid); eps=sscanf(tline,'%e',1);
tline=fgetl(fid); mt=sscanf(tline,'%d',1);
tline=fgetl(fid); CFL=sscanf(tline,'%e',1);
tline=fgetl(fid); IE=sscanf(tline,'%d',1);
tline=fgetl(fid); PP=sscanf(tline,'%d',1);
if PP == 1
  tline=fgetl(fid); CL=sscanf(tline,'%e',1);
  tline=fgetl(fid); CP=sscanf(tline,'%e',1);
  tline=fgetl(fid); uL=sscanf(tline,'%e',1);
  tline=fgetl(fid); uS=sscanf(tline,'%e',1);
  tline=fgetl(fid); uP=sscanf(tline,'%e',1);
end  
fclose(fid);
fprintf('\n********************************************************\n\n');
fprintf('delka intervalu                  : %13.2f\n',L);
fprintf('pocet bunek                      : %13d\n',N);
fprintf('koncovy cas                      : %13.4f\n',T);
fprintf('vystup v casech 0:T/M:T, kde M = : %13d\n',M);
fprintf('koeficient diffuze               : %13.6e\n',eps);
fprintf('konstanta CFL                    : %13.2f\n',CFL);
fprintf('metoda zpracovani difuze         : %s\n',euler(IE+1,:));
fprintf('metoda                           : %s\n',met(mt,:));
fprintf('typ pocatecni podminky           : %13d\n',PP);
if PP == 1 % pocatecni podminka pro Riemannuv problem
  fprintf('poloha leve prepazky             : %13.2f\n',CL);
  fprintf('poloha prave prepazky            : %13.2f\n',CP);
  fprintf('hodnota vlevo od leve prepazky   : %13.2f\n',uL);
  fprintf('hodnota mezi prepazkami          : %13.2f\n',uS);
  fprintf('hodnota vpravo od prave          : %13.2f\n',uP);  
  fid=fopen('poc.txt','wt'); % zapis do pomocneho souboru
  fprintf(fid,'%e\n%e\n%e\n%e\n%e',CL,CP,uL,uS,uP);
  fclose(fid);  
end
fprintf('\n********************************************************\n');
fprintf('\n***vypocet zahajen\n');
%% vypocet
tic;
[u,xout,tout,pk]=brg1(L,T,N,M,eps,mt,CFL,IE,PP);
% vstupni parametry m-funkce brg1:
%
% L   ... delka intervalu v ose x
% T   ... doba reseni
% N   ... pocet bunek
% M   ... pocet casovych vrstev pro vystup vysledku, vysledky se 
%         ukladaji do pole u v casech i*T/M, i=0,1,...,M
% dif ... difuzni koeficient
% met ... metoda vypoctu toku
% CFL ... CFL konstanta
% IE  ... zpracovani difuzniho clenu, IE = 0 ... explicitni Eulerova metoda
%                                     IE = 1 ... imlicitni Eulerova metoda
% PP  ...  typ pocatecni podminky, vybira se v m-funkci u0.m
%
% Vystupni parametry m-funkce brg1:
%
% u    ... vysledky, pole typu (N+2) x (M+1), tj. v i-tem sloupci
%          je napocitane reseni v case tout(i)=(i-1)*T/M, i=0,1,...,M
% xout ... body na ose x, ve kterych je napocitane reseni,
%          x(1)=0, x(i+1)=(i-1/2)*h, i=1,2,...,N, x(N+2)=L, pricemz h=L/N
% tout ... casy, ve kterych je napocitane reseni, tout(i)=(i-1)*T/M,
%          i=0,1,...,M
% pk   ... pocet provedenych kroku

soltime=toc;
fprintf(['***vypocet ukoncen, spotrebovany cas %6.2f\n',...
         '   pocet provedenych kroku %d\n\n'],soltime,pk);
%% vykresleni
cFigure=[1,0.8,0.8];    % barva okraje obrazku
cAxes=[0.58 0.58 0.58]; % barva pozadi uvnitr obrazku
cGrafF=[1 1 0.5];  % barva reseni
ymin=min(u(:,1)); % uprava velikosti obrazku
ymax=max(u(:,1));
dx=0.1*L;
dy=0.1*(ymax-ymin);

while true 
  fprintf(['zadej: i < 0 ... konec\n',...
           '       i in [0,%2d] => vystup v case tout(i+1): '],M);
  i=input('');       
  if isempty(i), return; end
  figure(1);
  clf;
  set(gcf,'Color',cFigure); % barva ramecku obrazku
  set(gca,'Color',cAxes); % barva uvnitr obrazku
  axis([-dx L+dx ymin-dy ymax+dy]);
  line(xout,u(:,i+1),'Color',cGrafF,'LineWidth',0.5);   
  grid on;
  title(sprintf('metoda = %s,  cas = %10.2f',met(mt,:),tout(i+1)));
  %shg;
end

